@@ -37,6 +37,8 @@ public slots:
     void onTimeout();
     void onSliderChanged(int value);
     void onTimeSigChange(int i);
+    void onBtnPlus();
+    void onBtnMinus();
 #ifdef Q_WS_MAEMO_5
     void orientationChanged(const QString &newOrientation);
 #endif
